@@ -3,7 +3,6 @@
 # Copyright (c) Bo Peng and the University of Texas MD Anderson Cancer Center
 # Distributed under the terms of the 3-clause BSD License.
 
-import sys
 import time
 
 from sos.hosts import Host
@@ -56,9 +55,6 @@ class Interactive_Step_Executor(Base_Step_Executor):
         # when we wait, the "outsiders" also need to see the tags etc
         # of the tasks so we have to write to the database. #156
         env.master_push_socket.send_pyobj(['commit_sig'])
-        if all_submitted and 'shared' not in env.sos_dict['_runtime']:
-            # if no shared and all taks have been submited return
-            sys.exit(0)
         # turn this function to a generator to satisfy the interface, but do not
         # actually wait for any socket.
         yield None
